Changes in directory llvm/include/llvm/CodeGen:

SelectionDAGNodes.h updated: 1.144 -> 1.145
---
Log message:

Implement new fpowi node


---
Diffs of the changes:  (+4 -3)

 SelectionDAGNodes.h |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/CodeGen/SelectionDAGNodes.h
diff -u llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.144 
llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.145
--- llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.144 Sun Aug 27 03:07:55 2006
+++ llvm/include/llvm/CodeGen/SelectionDAGNodes.h       Sat Sep  9 00:55:44 2006
@@ -361,9 +361,10 @@
     // conversions, but that is a noop, deleted by getNode().
     BIT_CONVERT,
     
-    // FNEG, FABS, FSQRT, FSIN, FCOS - Perform unary floating point negation,
-    // absolute value, square root, sine and cosine operations.
-    FNEG, FABS, FSQRT, FSIN, FCOS,
+    // FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI - Perform unary floating point
+    // negation, absolute value, square root, sine and cosine, and powi
+    // operations.
+    FNEG, FABS, FSQRT, FSIN, FCOS, FPOWI,
     
     // Other operators.  LOAD and STORE have token chains as their first
     // operand, then the same operands as an LLVM load/store instruction, then 
a



_______________________________________________
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits

Reply via email to